package xyz.thastertyn.UserInterface.Content;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;

import com.googlecode.lanterna.TextColor;
import com.googlecode.lanterna.TextColor.ANSI;
import com.googlecode.lanterna.graphics.SimpleTheme;
import com.googlecode.lanterna.gui2.Direction;
import com.googlecode.lanterna.gui2.GridLayout;
import com.googlecode.lanterna.gui2.Label;
import com.googlecode.lanterna.gui2.LayoutData;
import com.googlecode.lanterna.gui2.LinearLayout;
import com.googlecode.lanterna.gui2.Panel;
import com.googlecode.lanterna.gui2.WindowBasedTextGUI;

import xyz.thastertyn.Types.Predmet;
import xyz.thastertyn.Types.Znamka;
import xyz.thastertyn.UserInterface.Dialogs.OptionsDialog;

public class Znamky extends JecnaContent {

	private final TextColor.RGB VYBORNY = new TextColor.RGB(85,212,0);
	private final TextColor.RGB CHVALITEBNY = new TextColor.RGB(196,224,80);
	private final TextColor.RGB DOBRY = new TextColor.RGB(255,213,42);
	private final TextColor.RGB DOSTATECNY = new TextColor.RGB(255,102,0);
	private final TextColor.RGB NEDOSTATECNY = new TextColor.RGB(255,48,48);
	private final TextColor.RGB NEHODNOCEN = new TextColor.RGB(0,0,0);

	private final LayoutData ALIGN_LEFT = GridLayout.createLayoutData(
		GridLayout.Alignment.BEGINNING,
		GridLayout.Alignment.BEGINNING,
		false,
		false);

	private final LayoutData ALIGN_RIGHT = GridLayout.createLayoutData(
		GridLayout.Alignment.END,
		GridLayout.Alignment.BEGINNING,
		true,
		false);
	
	private Panel mainPanel = new Panel()
	.setLayoutManager(new GridLayout(3));

	private Label borderLabel = new Label("Znamky");
	private xyz.thastertyn.Scrape.Znamky znamky = new xyz.thastertyn.Scrape.Znamky();
	
	private boolean hasStarted = false;

	@Override
	public void download()
	{
		try{
			znamky.downloadZnamky();
			
			ArrayList<Predmet> predmety = znamky.getPredmety();
			
			HashMap<Integer, SimpleTheme> barvy = new HashMap<>();
			barvy.put(1, new SimpleTheme(ANSI.BLACK, VYBORNY));
			barvy.put(2, new SimpleTheme(ANSI.BLACK, CHVALITEBNY));
			barvy.put(3, new SimpleTheme(ANSI.BLACK, DOBRY));
			barvy.put(4, new SimpleTheme(ANSI.BLACK, DOSTATECNY));
			barvy.put(5, new SimpleTheme(ANSI.BLACK, NEDOSTATECNY));
			barvy.put(-1, new SimpleTheme(ANSI.WHITE, NEHODNOCEN));

			// Sloupec pro jmena predmetu
			Panel jmemaPredmetu = new Panel()
			.setLayoutManager(new LinearLayout(Direction.VERTICAL))
			.setLayoutData(ALIGN_LEFT)
			.addTo(mainPanel);
		
			// Sloupec pro znamky z predmetu
			Panel znamky = new Panel()
			.setLayoutManager(new LinearLayout(Direction.VERTICAL))
			.setLayoutData(ALIGN_LEFT)
			.addTo(mainPanel);

			// Sloupec pro vyslednou znamku
			Panel vysledneZnamky = new Panel()
			.setLayoutManager(new LinearLayout(Direction.VERTICAL))
			.setLayoutData(ALIGN_RIGHT)
			.addTo(mainPanel);

			for(Predmet predmet : predmety)
			{
				Panel jednotliveZnamky = new Panel()
				.setLayoutManager(new LinearLayout(Direction.HORIZONTAL))
				.addTo(znamky);

				if(predmet.getZnamky().isEmpty())
				{
					jednotliveZnamky.addComponent(new Label(""));
				}

				for(Znamka znamka : predmet.getZnamky())
				{
					Label znamkaLabel = new Label(znamka.getText());
					znamkaLabel.setTheme(barvy.get(znamka.getZnamka()));
					jednotliveZnamky.addComponent(znamkaLabel);
				}
				
				double prumer = predmet.getPrumer();

				Label vysl = new Label(String.format("%.2f", prumer));
				
				vysl.setTheme(barvy.get((int) Math.round(prumer)));
				
				jmemaPredmetu.addComponent(new Label(predmet.getJmenoPredmetu()));
				vysledneZnamky.addComponent(vysl);
			}

			hasStarted = true;
		}catch(IOException e)
		{
			mainPanel.addComponent(new Label("An error has occured"));
		}
	}

	@Override
	public Panel getPanel()
	{
		return mainPanel;
	}

	@Override
	public boolean hasStarted()
	{
		return hasStarted;
	}

	@Override
	public Label getLabel()
	{
		return borderLabel;
	}

	@Override
	public void showOptions(WindowBasedTextGUI textGUI) {
		OptionsDialog d = new OptionsDialog(znamky.getOptions().getValue0(), znamky.getOptions().getValue1());

		d.showDialog(textGUI);
	}
}